#!/bin/ksh

ECHO="/bin/echo"

$ECHO "   "
$ECHO "Install Fixpack 5.1.1.3 for WebSphere Commerce Suite, AIX"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "   "


# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <wcs_home> <was_home>"
   $ECHO "Example: ./install.sh /usr/lpp/CommerceSuite /usr/IBMWebAS"
}


# checks if required directories exist.
check_paths() {
local val=1

   if [ -d $WCS_HOME ] && val=2 && [ -d $WAS_HOME ]
   then
#   	$ECHO "---- Components path check passed -----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "Invalid WCS_HOME directory."
	      ;;
	   2) $ECHO "Invalid WAS_HOME directory."
	      ;;
	esac
   fi

   return $FALSE
}


# checks if required files exist.
check_files() {
local val=1

   if [ -f $WAS_HOME/java/jre/sh/java ] && val=2 && \
      [ -f ./WCSfixpack5113_AIX.jar ] && val=3 && \
      [ -f ./Delta.jar ]
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: $WAS_HOME/java/jre/sh/java"
	      ;;
	   2) $ECHO "The following file does not exist: $WCS_PTF"
	      ;;
	   3) $ECHO "The following file does not exist: $DELTA_JAR"
	      ;;
	esac
   fi

   return $FALSE;
}


# make service directories
make_service_dir() {

   if [ -d $WCS_SERVICE_DIR ]; then
   	if [ -d $WCS_FIXPACK_DIR ]; then
	   if [ -d $WCS_FP5113_DIR ]; then
	      return
	   else
	      mkdir $WCS_FP5113_DIR
	   fi
	else
	   mkdir $WCS_FIXPACK_DIR
	   mkdir $WCS_FP5113_DIR
	fi
   else
      mkdir $WCS_SERVICE_DIR
      mkdir $WCS_FIXPACK_DIR
      mkdir $WCS_FP5113_DIR
   fi
}

# beginning of script.
#clear

TRUE=0
FALSE=1

WCS_PTF="WCSfixpack5113_AIX.jar"
DELTA_JAR="Delta.jar"


#ensure correct number of arguments provided.
if [ $# -ne 2 ]; then
   print_usage
   exit 0
else
   WCS_HOME=$1
   WAS_HOME=$2
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi


WCS_SERVICE_DIR="$WCS_HOME/service"
WCS_FIXPACK_DIR="$WCS_HOME/service/fixpack"
WCS_FP5113_DIR="$WCS_HOME/service/fixpack/5113"


# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi


# make service directories
make_service_dir
$ECHO "main - service directories exist/created."


# Install Fixpack 5.1.1.3 for WebSphere Commerce Suite, AIX
$ECHO "main - installing fixpack."

$WAS_HOME/java/jre/sh/java -jar $WCS_PTF -TargetDir $WCS_HOME -backupJar $WCS_FP5113_DIR/WCSfixpack5113_AIX_backup.jar -log $WCS_FP5113_DIR/WCSfixpack5113_AIX.log -SkipVer

$ECHO "main - installing fixpack complete."

exit 0
